@@ -10,6 +10,7 @@ import requests
 import calendar
 
 import pandas as pd
+import numpy as np
 
 from datetime import  timedelta
 
@@ -106,24 +107,24 @@ class NaPoleonBinanceFutureBot(object):
         return result_df
 
     def get_futures_positions_margin_change_history(self, assets, start_time, end_time):
-        transfer_df = None
+        positions_margin_change_df = None
         for asset in assets:
-            if transfer_df is None:
-                transfer_df = self.get_futures_positiion_margin_change_history(asset, start_time, end_time)
+            if positions_margin_change_df is None:
+                positions_margin_change_df = self.get_futures_position_margin_change_history(asset, start_time, end_time)
             else:
-                add_transfer_df = self.get_futures_positiion_margin_change_history(asset, start_time, end_time)
+                add_transfer_df = self.get_futures_position_margin_change_history(asset, start_time, end_time)
                 if add_transfer_df is not None:
-                    transfer_df = pd.concat([transfer_df, add_transfer_df])
-        if transfer_df is not None:
-            return transfer_df[['date','asset','amount']]
-        return transfer_df
+                    positions_margin_change_df = pd.concat([positions_margin_change_df, add_transfer_df])
+        if positions_margin_change_df is not None:
+            return positions_margin_change_df[['date','asset','amount']]
+        return positions_margin_change_df
 
-    def get_futures_positiion_margin_change_history(self, asset, start_time, end_time):
+    def get_futures_position_margin_change_history(self, asset, start_time, end_time):
 
         startTime = int(start_time.timestamp() * 1000)
         endTime = int(end_time.timestamp() * 1000)
 
-        BASE_URL = 'https://api.binance.com'
+        BASE_URL = 'https://fapi.binance.com'
         PATH = '/fapi/v1/positionMargin/history'
 
 
@@ -138,8 +139,8 @@ class NaPoleonBinanceFutureBot(object):
             'timestamp': timestamp,
             'startTime': startTime,
             'endTime': endTime,
-            # 'limit': 500,
-            # 'type':1
+##            'limit': 500,
+##           'type':2
         }
         query_string = urllib.parse.urlencode(params)
         params['signature'] = hmac.new(self.secret.encode('utf-8'), query_string.encode('utf-8'),
@@ -163,7 +164,7 @@ class NaPoleonBinanceFutureBot(object):
     def get_future_position_risk(self):
 
 
-        BASE_URL = 'https://api.binance.com'
+        BASE_URL = 'https://fapi.binance.com'
         PATH = '/fapi/v2/positionRisk'
 
 
@@ -183,16 +184,7 @@ class NaPoleonBinanceFutureBot(object):
         print(url)
         r = requests.get(url, headers=headers, params=params)
         dataSet = r.json()
-        if dataSet['total']>0:
-            transfers = dataSet['rows']
-
-            transfer_df = pd.DataFrame(transfers)
-
-            transfer_df['date'] = pd.to_datetime(transfer_df['timestamp'], unit='ms')
-
-            return transfer_df
-        else :
-            return None
+        return dataSet
 
     def get_futures_transfer_history(self, assets, start_time, end_time):
         transfer_df = None
@@ -204,7 +196,7 @@ class NaPoleonBinanceFutureBot(object):
                 if add_transfer_df is not None:
                     transfer_df = pd.concat([transfer_df, add_transfer_df])
         if transfer_df is not None:
-            return transfer_df[['date','asset','amount']]
+            return transfer_df[['date','asset','amount','type']]
         return transfer_df
 
     def get_coin_futures_transfer_history(self, asset, start_time, end_time):
@@ -239,7 +231,6 @@ class NaPoleonBinanceFutureBot(object):
         dataSet = r.json()
         if dataSet['total']>0:
             transfers = dataSet['rows']
-
             transfer_df = pd.DataFrame(transfers)
 
             transfer_df['date'] = pd.to_datetime(transfer_df['timestamp'], unit='ms')
