@@ -449,16 +449,28 @@ def fetch_all_necessary_data(public_key = None, private_key= None, start_time= N
         fut_transfers = pd.merge(fut_transfers, ohlc_bnb_min_binance[['ts', 'open']], how='left', left_on='date',
                                right_on='ts')
 
-        def convert_trans_bnb_to_usdt(row):
-            print(row)
+        def convert_and_proper_signtrans_bnb_to_usdt(row):
+            sign = 1
+            if row['type'] == 2:
+                sign = -1.
+            elif row['type'] == 1:
+                sign = 1.
+            else:
+                # coin-m future account : we cancel
+                sign = 0.
+
             if row['asset'] == 'BNB':
-                return float(row['amount']) * float(row['open'])
+                return float(row['amount']) * float(row['open']) * sign
             elif row['asset'] == 'USDT':
-                return float(row['amount'])
-            else :
+                return float(row['amount']) * sign
+            else:
                 return np.nan
-        fut_transfers['fut_transfer_usdt_amount'] = fut_transfers.apply(convert_trans_bnb_to_usdt, axis=1)
-        fut_transfers = fut_transfers[['date','fut_transfer_usdt_amount']].groupby('date').sum()
+
+        fut_transfers['fut_transfer_usdt_amount'] = fut_transfers.apply(convert_and_proper_signtrans_bnb_to_usdt,
+                                                                        axis=1)
+
+        fut_transfers = fut_transfers[['date', 'fut_transfer_usdt_amount']].groupby('date').sum()
+
 
 
 
